# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Config file for Pytest, where directory-wide fixtures are defined"""
from pathlib import Path

import pytest


@pytest.fixture
def rootDirectory() -> str:
    return "/tmp/workspaces_tmp"


@pytest.fixture
def processingDirectory() -> str:
    return "tmpiox5trbp"


@pytest.fixture
def parent_path() -> Path:
    return Path("I/am/a/path")


@pytest.fixture
def cal_settings(rootDirectory, processingDirectory, parent_path) -> dict:
    return {
        "useCasa": False,
        "homeForReprocessing": "/home/casa/packages/pipeline/current",
        "rootDirectory": rootDirectory,
        "processingDirectory": processingDirectory,
        "metadata": "test/input_files/test.json",
        "ppr": "test/input_files/PPR.xml",
        "product_type": "standard-cal",
        "parent_path": parent_path,
    }


@pytest.fixture
def img_settings(rootDirectory, processingDirectory, parent_path) -> dict:
    return {
        "useCasa": False,
        "homeForReprocessing": "/home/casa/packages/pipeline/current",
        "rootDirectory": rootDirectory,
        "processingDirectory": processingDirectory,
        "metadata": "test/input_files/image-metadata.json",
        "ppr": "test/input_files/cmsimage-PPR.xml",
        "product_type": "standard-img",
        "parent_path": parent_path,
    }
